This data can be used to teach correlation.

dat_draft

Format

A data frame with columns:

day_month

A value between 1924 and 2015.

day_year

Maple products expressed as syrup, total in thousands of gallons.

month

Gross value of maple products in thousands of Canadian dollars.

month_name

Postal code abbreviation for territory or province.

n69

1969 draft order

n70

1970 draft order

n71

1971 draft order

n72

1972 draft order

https://www.randomservices.org/random/data/Draft.html

Examples

if (FALSE) { dat_draft }