dpr_create_github.RdGithub Repo Create
dpr_create_github(owner_name, repo_name, public = TRUE, group = TRUE)
| owner_name | is the name of the org or user that owns the repo. |
|---|---|
| repo_name | is the name of the created data R package and repository name. |
| group | defaults to TRUE and uses the group POST command to a org if FALSE uses users POST command. |