Document data file as a readme or as `data.R` for use when building to `.Rd` file for an R package.

--desc--

dpr_document(
  data_object,
  extension = "md",
  export_folder = "R",
  object_name = "pdat",
  title = "My title of my data",
  description = "Short Description",
  source = "Where the data was found",
  format = "A data frame with columns:",
  var_details = list(day_month = "The numbered day of the month", day_year =
    "The numbered day of the year"),
  append = TRUE,
  details = TRUE
)

Arguments

data_object

is an R data frame.

extension

is a character vector of formats to build. Defaults to "md". Potential extensions are `md` and `R`. If both documents are desired then `mdR` or any combination can be used to get both.

export_folder

is the folder where the data document files will be placed. If the extension is `.R` then the `export_folder` will have the subdirectory `R` added.

object_name

is the name of the data object for an R package data set or the name of the file for and md extension.

title

is the title of the data.

description

is a short description of the data. If NULL then not used.

source

is a description of the source of the data.

format

defaults to the text "A data frame with columns:" and is generally the best text to use.

var_details

a list with the column name and the column description.

append

Defaults to TRUE. If TRUE then the new data text for `data.R` or the `readme.md` will be appended. If FALSE then the files will be overwritten.

details

If TRUE then information is printed to screen during the process. Default is TRUE.

Format

a text object is returned and a file is writtern to the folder specificed named data.

--format-- \describe

\url--source--

Examples