dpr_push.RdConnect to remote, Commit and Push Latest Updates to Repo
dpr_push( folder_dir = "/Users/hathawayj/git/temp_data/Test3", message = "'First Push from Hathaway'", repo_url = NULL )
| folder_dir | is the folder on your local computer where you store your git repository |
|---|---|
| message | is the commit message to use |
| repo_url | is the https url from GitHub. If NULL remote connect call not run |