dpr_readme.RdCreate readme.md in repo
dpr_readme(folder_dir, package_name, github_user)
| folder_dir | is the folder on your local computer where you store your git repository |
|---|---|
| package_name | is the name of the created data R package. |
| github_user | is the Github group or user where the package is stored. |